==> aa_ledger-0.5.2a2-py3-none-any.whl: ledger/tests/test_api/_ledgercorpdata.py <==
noData = [
    {
        "ratting": [],
        "total": {
            "total_amount": "0.00",
            "total_amount_ess": "0.00",
            "total_amount_all": "0.00",
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": None,
            "rattingbar": None,
            "workflowgauge": [],
        },
    }
]

CorpmonthlyMarch = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "alt_names": [],
                "total_amount": "200000.00",
                "total_amount_ess": "200000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "200000.00",
            "total_amount_all": "400000.00",
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": [
                ["Gneuten", "100"],
            ],
            "rattingbar": [
                [
                    "x",
                    "2024-03-01",
                    "2024-03-02",
                    "2024-03-03",
                    "2024-03-04",
                    "2024-03-05",
                    "2024-03-06",
                    "2024-03-07",
                    "2024-03-08",
                    "2024-03-09",
                    "2024-03-10",
                    "2024-03-11",
                    "2024-03-12",
                    "2024-03-13",
                    "2024-03-14",
                    "2024-03-15",
                    "2024-03-16",
                    "2024-03-17",
                    "2024-03-18",
                    "2024-03-19",
                    "2024-03-20",
                    "2024-03-21",
                    "2024-03-22",
                    "2024-03-23",
                    "2024-03-24",
                    "2024-03-25",
                    "2024-03-26",
                    "2024-03-27",
                    "2024-03-28",
                    "2024-03-29",
                    "2024-03-30",
                    "2024-03-31",
                ],
                [
                    "Ratting",
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                [
                    "ESS Payout",
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                ["Miscellaneous"],
                ["Mining"],
            ],
            "workflowgauge": [],
        },
    }
]

Corpyearly = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "alt_names": [],
                "total_amount": "200000.00",
                "total_amount_ess": "200000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "200000.00",
            "total_amount_all": "400000.00",
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": [
                ["Gneuten", "100"],
            ],
            "rattingbar": [
                [
                    "x",
                    "2024-01",
                    "2024-02",
                    "2024-03",
                    "2024-04",
                    "2024-05",
                    "2024-06",
                    "2024-07",
                    "2024-08",
                    "2024-09",
                    "2024-10",
                    "2024-11",
                    "2024-12",
                ],
                [
                    "Ratting",
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                [
                    "ESS Payout",
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                ["Miscellaneous"],
                ["Mining"],
            ],
            "workflowgauge": [],
        },
    }
]

Corpdatamany = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "alt_names": [],
                "total_amount": "200000.00",
                "total_amount_ess": "200000.00",
            },
            {
                "main_id": 1010,
                "main_name": "Test1",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1019,
                "main_name": "Test10",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1020,
                "main_name": "Test11",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1021,
                "main_name": "Test12",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1011,
                "main_name": "Test2",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1012,
                "main_name": "Test3",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1013,
                "main_name": "Test4",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1014,
                "main_name": "Test5",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1015,
                "main_name": "Test6",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1016,
                "main_name": "Test7",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1017,
                "main_name": "Test8",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1018,
                "main_name": "Test9",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
        ],
        "total": {
            "total_amount": "1400000.00",
            "total_amount_ess": "200000.00",
            "total_amount_all": "1600000.00",
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": [
                ["Gneuten", "14.28571428571428571428571429"],
                ["Test1", "7.142857142857142857142857143"],
                ["Test10", "7.142857142857142857142857143"],
                ["Test11", "7.142857142857142857142857143"],
                ["Test12", "7.142857142857142857142857143"],
                ["Test2", "7.142857142857142857142857143"],
                ["Test3", "7.142857142857142857142857143"],
                ["Test4", "7.142857142857142857142857143"],
                ["Test5", "7.142857142857142857142857143"],
                ["Test6", "7.142857142857142857142857143"],
                ["Others", "21.42857142857142857142857143"],
            ],
            "rattingbar": [
                [
                    "x",
                    "2024-03-01",
                    "2024-03-02",
                    "2024-03-03",
                    "2024-03-04",
                    "2024-03-05",
                    "2024-03-06",
                    "2024-03-07",
                    "2024-03-08",
                    "2024-03-09",
                    "2024-03-10",
                    "2024-03-11",
                    "2024-03-12",
                    "2024-03-13",
                    "2024-03-14",
                    "2024-03-15",
                    "2024-03-16",
                    "2024-03-17",
                    "2024-03-18",
                    "2024-03-19",
                    "2024-03-20",
                    "2024-03-21",
                    "2024-03-22",
                    "2024-03-23",
                    "2024-03-24",
                    "2024-03-25",
                    "2024-03-26",
                    "2024-03-27",
                    "2024-03-28",
                    "2024-03-29",
                    "2024-03-30",
                    "2024-03-31",
                ],
                [
                    "Ratting",
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    1400000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                [
                    "ESS Payout",
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                ["Miscellaneous"],
                ["Mining"],
            ],
            "workflowgauge": [],
        },
    }
]

==> aa_ledger-0.5.3-py3-none-any.whl: ledger/tests/test_api/_ledgercorpdata.py <==
noData = [
    {
        "ratting": [],
        "total": {
            "total_amount": 0,
            "total_amount_ess": 0,
            "total_amount_all": 0,
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": None,
            "rattingbar": None,
            "workflowgauge": [],
        },
    }
]

CorpmonthlyMarch = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "alt_names": [],
                "total_amount": "200000.00",
                "total_amount_ess": "200000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "200000.00",
            "total_amount_all": "400000.00",
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": [
                ["Gneuten", "100"],
            ],
            "rattingbar": [
                [
                    "x",
                    "2024-01",
                    "2024-02",
                    "2024-03",
                    "2024-04",
                    "2024-05",
                    "2024-06",
                    "2024-07",
                    "2024-08",
                    "2024-09",
                    "2024-10",
                    "2024-11",
                    "2024-12",
                ],
                [
                    "Ratting",
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                [
                    "ESS Payout",
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                ["Miscellaneous"],
                ["Mining"],
            ],
            "workflowgauge": [],
        },
    }
]


Corpyearly = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "alt_names": [],
                "total_amount": "200000.00",
                "total_amount_ess": "200000.00",
            }
        ],
        "total": {
            "total_amount": "200000.00",
            "total_amount_ess": "200000.00",
            "total_amount_all": "400000.00",
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": [
                ["Gneuten", "100"],
            ],
            "rattingbar": [
                [
                    "x",
                    "2024-01",
                    "2024-02",
                    "2024-03",
                    "2024-04",
                    "2024-05",
                    "2024-06",
                    "2024-07",
                    "2024-08",
                    "2024-09",
                    "2024-10",
                    "2024-11",
                    "2024-12",
                ],
                [
                    "Ratting",
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                [
                    "ESS Payout",
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                ["Miscellaneous"],
                ["Mining"],
            ],
            "workflowgauge": [],
        },
    }
]

Corpdatamany = [
    {
        "ratting": [
            {
                "main_id": 1001,
                "main_name": "Gneuten",
                "alt_names": [],
                "total_amount": "200000.00",
                "total_amount_ess": "200000.00",
            },
            {
                "main_id": 1010,
                "main_name": "Test1",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1019,
                "main_name": "Test10",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1020,
                "main_name": "Test11",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1021,
                "main_name": "Test12",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1011,
                "main_name": "Test2",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1012,
                "main_name": "Test3",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1013,
                "main_name": "Test4",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1014,
                "main_name": "Test5",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1015,
                "main_name": "Test6",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1016,
                "main_name": "Test7",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1017,
                "main_name": "Test8",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
            {
                "main_id": 1018,
                "main_name": "Test9",
                "alt_names": [],
                "total_amount": "100000.00",
                "total_amount_ess": "0.00",
            },
        ],
        "total": {
            "total_amount": "1400000.00",
            "total_amount_ess": "200000.00",
            "total_amount_all": "1600000.00",
            "total_amount_mining": 0,
            "total_amount_others": 0,
            "total_amount_costs": 0,
        },
        "billboard": {
            "walletcharts": [],
            "charts": [
                ["Gneuten", "14.28571428571428571428571429"],
                ["Test1", "7.142857142857142857142857143"],
                ["Test10", "7.142857142857142857142857143"],
                ["Test11", "7.142857142857142857142857143"],
                ["Test12", "7.142857142857142857142857143"],
                ["Test2", "7.142857142857142857142857143"],
                ["Test3", "7.142857142857142857142857143"],
                ["Test4", "7.142857142857142857142857143"],
                ["Test5", "7.142857142857142857142857143"],
                ["Test6", "7.142857142857142857142857143"],
                ["Others", "21.42857142857142857142857143"],
            ],
            "rattingbar": [
                [
                    "x",
                    "2024-03-01",
                    "2024-03-02",
                    "2024-03-03",
                    "2024-03-04",
                    "2024-03-05",
                    "2024-03-06",
                    "2024-03-07",
                    "2024-03-08",
                    "2024-03-09",
                    "2024-03-10",
                    "2024-03-11",
                    "2024-03-12",
                    "2024-03-13",
                    "2024-03-14",
                    "2024-03-15",
                    "2024-03-16",
                    "2024-03-17",
                    "2024-03-18",
                    "2024-03-19",
                    "2024-03-20",
                    "2024-03-21",
                    "2024-03-22",
                    "2024-03-23",
                    "2024-03-24",
                    "2024-03-25",
                    "2024-03-26",
                    "2024-03-27",
                    "2024-03-28",
                    "2024-03-29",
                    "2024-03-30",
                    "2024-03-31",
                ],
                [
                    "Ratting",
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    1400000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                [
                    "ESS Payout",
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    200000,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                    0,
                ],
                ["Miscellaneous"],
                ["Mining"],
            ],
            "workflowgauge": [],
        },
    }
]
